// Generated by CoffeeScript 1.8.0
var app, args, bits, compile, compiler, compilers, conf, confs, credentials, cwd, defaultExclude, err, error, excludeRe, exec, ext, fs, log, mod, opt, opts, os, re, requireConfig, server, usage, vigil, websocket, _i, _j, _len, _len1, _ref, _ref1, _ref2, _ref3, _ref4;

exec = require('executive');

fs = require('fs');

os = require('os');

vigil = require('vigil');

compilers = require('./compilers');

server = require('./server');

_ref = require('./utils'), defaultExclude = _ref.defaultExclude, log = _ref.log;

error = function(message) {
  console.error(message);
  return process.exit(1);
};

usage = function() {
  console.log("bebop [options]\n\nOptions:\n  --config, -c    Specify bebop.coffee to use\n  --compilers,    Specify compiler to use for a given extension\n  --compile-only  Compile files and exit\n  --exclude, -x   Exclude files from being watched/compiled\n  --force-reload  Force reload when file is compiled\n  --host, -h      Hostname to bind to\n  --no-compile    Do not compile files automatically\n  --no-watch      Do not watch files for changes\n  --no-server     Do not run static file server\n  --open, -o      Open browser automatically\n  --port, -p      Port to listen on\n  --secure, -s    Require authentication");
  return process.exit(0);
};

require.extensions['.coffee'] = function() {
  require('coffee-script/register');
  return require.extensions['.coffee'].apply(require.extensions, arguments);
};

cwd = process.cwd();

confs = [process.env.HOME + '/.bebop', cwd + '/.bebop', cwd + '/bebop'];

opts = {
  compile: true,
  compileOnly: false,
  compilers: {},
  cwd: cwd,
  defaultExclude: true,
  exclude: [],
  forceReload: false,
  host: 'localhost',
  port: 1987,
  runServer: true,
  watch: true
};

requireConfig = function(path) {
  var conf, err, k, v, _ref1, _results;
  try {
    conf = require.resolve(path);
  } catch (_error) {
    err = _error;
    return;
  }
  if (fs.existsSync(conf)) {
    _ref1 = require(conf);
    _results = [];
    for (k in _ref1) {
      v = _ref1[k];
      _results.push(opts[k] = v);
    }
    return _results;
  }
};

for (_i = 0, _len = confs.length; _i < _len; _i++) {
  conf = confs[_i];
  requireConfig(conf);
}

args = process.argv.slice(2);

while (opt = args.shift()) {
  switch (opt) {
    case '--help':
    case '-v':
      usage();
      break;
    case '--config':
    case '-c':
      requireConfig(args.shift());
      break;
    case '--open':
    case '-o':
      opts.open = true;
      break;
    case '--no-server':
      opts.runServer = false;
      break;
    case '--no-watch':
      opts.watch = false;
      break;
    case '--no-compile':
      opts.compile = false;
      break;
    case '--compile-only':
      opts.compileOnly = true;
      break;
    case '--exclude':
    case '-x':
      opts.exclude.push(new RegExp(args.shift()));
      break;
    case '--no-default-exclude':
      opts.defaultExclude = false;
      break;
    case '--force-reload':
      opts.forceReload = true;
      break;
    case '--host':
    case '-h':
      opts.host = args.shift();
      break;
    case '--port':
    case '-p':
      opts.port = parseInt(args.shift(), 10);
      break;
    case '--secure':
    case '-s':
      credentials = args.shift();
      if (credentials) {
        _ref1 = credentials.split(':'), opts.user = _ref1[0], opts.pass = _ref1[1];
      } else {
        opts.user = 'bebop';
        opts.pass = 'beepboop';
      }
      break;
    case '--compilers':
    case '-c':
      _ref2 = args.shift().split(',');
      for (_j = 0, _len1 = _ref2.length; _j < _len1; _j++) {
        compiler = _ref2[_j];
        _ref3 = compiler.split(':'), ext = _ref3[0], mod = _ref3[1];
        opts.compilers[ext] = mod;
      }
      break;
    default:
      if (opt.charAt(0) === '-') {
        error('Unrecognized option');
      }
  }
}

if (opts.defaultExclude) {
  opts.exclude = [vigil.utils.excludeRe, defaultExclude].concat(opts.exclude);
}

excludeRe = new RegExp(((function() {
  var _k, _len2, _ref4, _results;
  _ref4 = opts.exclude;
  _results = [];
  for (_k = 0, _len2 = _ref4.length; _k < _len2; _k++) {
    re = _ref4[_k];
    _results.push(re.source);
  }
  return _results;
})()).join('|'));

_ref4 = opts.compilers;
for (ext in _ref4) {
  compiler = _ref4[ext];
  if (typeof compiler === 'string') {
    try {
      bits = compiler.split('.');
      compiler = require(bits.shift());
      while (bits.length) {
        compiler = compiler[bits.shift()];
      }
      compilers[ext] = compiler;
    } catch (_error) {
      err = _error;
      console.log(err);
    }
  } else {
    compilers[ext] = compiler;
  }
}

compile = function(filename, cb) {
  if (cb == null) {
    cb = function() {};
  }
  return compilers.compile(filename, function(err, compiled) {
    if (filename.indexOf(opts.cwd === 0)) {
      filename = (filename.replace(opts.cwd, '')).replace(/^\//, '');
    }
    if (err != null) {
      log.error('error', "failed to compile " + filename);
      console.error(err.stderr != null ? err.stderr : err.stack);
      return;
    }
    if (compiled) {
      log.info('compiled', filename);
    }
    return cb(null, compiled);
  });
};

if (opts.runServer) {
  app = server.createServer(opts);
  websocket = (require('./websocket'))({
    server: app
  });
} else {
  app = {
    run: function() {}
  };
  websocket = {
    modified: function() {}
  };
}

if (opts.compile) {
  vigil.walk(opts.cwd, {
    exclude: excludeRe
  }, function(filename) {
    if (opts.compile) {
      return compile(filename);
    }
  });
}

if (!opts.compileOnly) {
  if (opts.watch) {
    vigil.watch(opts.cwd, function(filename, stat, isModule) {
      if (excludeRe.test(filename)) {
        return;
      }
      if (!opts.compile) {
        log.info('modified', filename);
        return websocket.modified(filename);
      }
      return compile(filename, function(err, compiled) {
        if (!compiled) {
          log.info('modified', filename);
          return websocket.modified(filename);
        } else {
          if (opts.forceReload) {
            return websocket.modified(filename);
          }
        }
      });
    });
  }
  app.run();
  if (opts.open) {
    switch (os.platform()) {
      case 'darwin':
        exec("open http://" + opts.host + ":" + opts.port);
        break;
      case 'linux':
        exec("xdg-open http://" + opts.host + ":" + opts.port);
    }
  }
}

//# sourceMappingURL=cli.js.map
